pub struct LightType(/* private fields */);Expand description
[docs.microsoft.com] D3DLIGHTTYPE
Defines the light type.
Directional lights are slightly faster than point light sources, but point lights look a little better. Spotlights offer interesting visual effects but are computationally time-consuming.
Implementations
Sourceimpl LightType
impl LightType
Sourcepub const fn from_unchecked(d3d: D3DLIGHTTYPE) -> Self
pub const fn from_unchecked(d3d: D3DLIGHTTYPE) -> Self
Convert from an underlying winapi D3D... type.
This is probably safe… probably…
Sourcepub const fn into(self) -> D3DLIGHTTYPE
pub const fn into(self) -> D3DLIGHTTYPE
Convert back into an underlying winapi D3D... type.
Sourceimpl LightType
impl LightType
Sourcepub const Point: LightType
pub const Point: LightType
Light is a point source. The light has a position in space and radiates light in all directions.
Sourcepub const Directional: LightType
pub const Directional: LightType
Light is a directional light source. This is equivalent to using a point light source at an infinite distance.