RS

Struct RS 

pub struct RS(/* private fields */);
[docs.microsoft.com] D3DRENDERSTATETYPE

Render states define set-up states for all kinds of vertex and pixel processing. Some render states set up vertex processing, and some set up pixel processing (see Render States (Direct3D 9)). Render states can be saved and restored using stateblocks (see State Blocks Save and Restore State (Direct3D 9)).

Implementations

Source

impl RS

pub const fn from_unchecked(d3d: D3DRENDERSTATETYPE) -> Self

Convert from an underlying winapi D3D... type. This is probably safe… probably…

pub const fn into(self) -> D3DRENDERSTATETYPE

Convert back into an underlying winapi D3D... type.

Source

impl RenderStateType

pub const ZEnable: RenderStateType

pub const FillMode: RenderStateType

pub const ShadeMode: RenderStateType

pub const ZWriteEnable: RenderStateType

pub const AlphaTestEnable: RenderStateType

pub const LastPixel: RenderStateType

pub const SrcBlend: RenderStateType

pub const DestBlend: RenderStateType

pub const CullMode: RenderStateType

pub const ZFunc: RenderStateType

pub const AlphaRef: RenderStateType

pub const AlphaFunc: RenderStateType

pub const DitherEnable: RenderStateType

pub const AlphaBlendEnable: RenderStateType

pub const FogEnable: RenderStateType

pub const SpecularEnable: RenderStateType

pub const FogColor: RenderStateType

pub const FogTableMode: RenderStateType

pub const FogStart: RenderStateType

pub const FogEnd: RenderStateType

pub const FogDensity: RenderStateType

pub const RangeFogEnable: RenderStateType

pub const StencilEnable: RenderStateType

pub const StencilFail: RenderStateType

pub const StencilZFail: RenderStateType

pub const StencilPass: RenderStateType

pub const StencilFunc: RenderStateType

pub const StencilRef: RenderStateType

pub const StencilMask: RenderStateType

pub const StencilWriteMask: RenderStateType

pub const TextureFactor: RenderStateType

pub const Wrap0: RenderStateType

pub const Wrap1: RenderStateType

pub const Wrap2: RenderStateType

pub const Wrap3: RenderStateType

pub const Wrap4: RenderStateType

pub const Wrap5: RenderStateType

pub const Wrap6: RenderStateType

pub const Wrap7: RenderStateType

pub const Clipping: RenderStateType

pub const Lighting: RenderStateType

pub const Ambient: RenderStateType

pub const FogVertexMode: RenderStateType

pub const ColorVertex: RenderStateType

pub const LocalViewer: RenderStateType

pub const NormalizeNormals: RenderStateType

pub const DiffuseMaterialSource: RenderStateType

pub const SpecularMaterialSource: RenderStateType

pub const AmbientMaterialSource: RenderStateType

pub const EmissiveMaterialSource: RenderStateType

pub const VertexBlend: RenderStateType

pub const ClipPlaneEnable: RenderStateType

pub const PointSize: RenderStateType

pub const PointSizeMin: RenderStateType

pub const PointSpriteEnable: RenderStateType

pub const PointScaleEnable: RenderStateType

pub const PointScaleA: RenderStateType

pub const PointScaleB: RenderStateType

pub const PointScaleC: RenderStateType

pub const MultiSampleAntiAlias: RenderStateType

pub const MultiSampleMask: RenderStateType

pub const PatchEdgeStyle: RenderStateType

pub const DebugMonitorToken: RenderStateType

pub const PointSizeMax: RenderStateType

pub const IndexedVertexBlendEnable: RenderStateType

pub const ColorWriteEnable: RenderStateType

pub const TweenFactor: RenderStateType

pub const BlendOp: RenderStateType

pub const PositionDegree: RenderStateType

pub const NormalDegree: RenderStateType

pub const ScissorTestEnable: RenderStateType

pub const SlopeScaleDepthBias: RenderStateType

pub const AntiAliasedLineEnable: RenderStateType

pub const MinTessellationLevel: RenderStateType

pub const MaxTessellationLevel: RenderStateType

pub const AdaptiveTessX: RenderStateType

pub const AdaptiveTessY: RenderStateType

pub const AdaptiveTessZ: RenderStateType

pub const AdaptiveTessW: RenderStateType

pub const EnableAdaptiveTessellation: RenderStateType

pub const TwoSidedStencilMode: RenderStateType

pub const CcwStencilFail: RenderStateType

pub const CcwStencilZFail: RenderStateType

pub const CcwStencilPass: RenderStateType

pub const CcwStencilFunc: RenderStateType

pub const ColorWriteEnable1: RenderStateType

pub const ColorWriteEnable2: RenderStateType

pub const ColorWriteEnable3: RenderStateType

pub const BlendFactor: RenderStateType

pub const SRGBWriteEnable: RenderStateType

pub const DepthBias: RenderStateType

pub const Wrap8: RenderStateType

pub const Wrap9: RenderStateType

pub const Wrap10: RenderStateType

pub const Wrap11: RenderStateType

pub const Wrap12: RenderStateType

pub const Wrap13: RenderStateType

pub const Wrap14: RenderStateType

pub const Wrap15: RenderStateType

pub const SeparateAlphaBlendEnable: RenderStateType

pub const SrcBlendAlpha: RenderStateType

pub const DestBlendAlpha: RenderStateType

pub const BlendOpAlpha: RenderStateType