Format

Struct Format 

pub struct Format(/* private fields */);
[docs.microsoft.com] D3DFORMAT

Enumeration cases are labeled in native endian.

RGBA Color Formats

FormatBits/PixelBack BufferDisplayNative Endian Bits
Format::UNKNOWNN/AN/AN/AN/A
Format::R8G8B824rrrrrrrrggggggggbbbbbbbb
Format::A8R8G8B832✔️aaaaaaaarrrrrrrrggggggggbbbbbbbb
Format::X8R8G8B832✔️✔️xxxxxxxxrrrrrrrrggggggggbbbbbbbb
Format::R5G6B516✔️✔️rrrrrggggggbbbbb
Format::X1R5G5B516✔️✔️xrrrrrgggggbbbbb
Format::A1R5G5B516✔️arrrrrgggggbbbbb
Format::A4R4G4B416aaaarrrrggggbbbb
Format::R3G3B28rrrgggbb
Format::A88aaaaaaaa
Format::A8R3G3B216aaaaaaaarrrgggbb
Format::X4R4G4B416xxxxrrrrggggbbbb
Format::A2B10G10R1032aabbbbbbbbbbggggggggggrrrrrrrrrr
Format::A8B8G8R832aaaaaaaabbbbbbbbggggggggrrrrrrrr
Format::X8B8G8R832xxxxxxxxbbbbbbbbggggggggrrrrrrrr
Format::G16R1632ggggggggggggggggrrrrrrrrrrrrrrrr
Format::A2R10G10B1032✔️✔️aarrrrrrrrrrggggggggggbbbbbbbbbb
Format::A16B16G16R1664AAAARRRRGGGGBBBB16
[Direct3DEx] Only
Format::A11a
Format::A2B10G10R10_XR_BIAS32???
KeyDescription
rrrrRed channel bits
ggggGreen channel bits
bbbbBlue channel bits
aaaaAlpha channel bits
xxxxUnused channel bits

Non-RGBA Color Formats

FormatBits/PixelNative Endian Bits
Format::A8P816aaaaaaaapppppppp
Format::P88pppppppp
Format::L88llllllll
Format::A8L816aaaaaaaallllllll
Format::A4L48aaaallll
Format::L1616llllllllllllllll
KeyDescription
aaaaAlpha channel bits
ppppPallete index bits
llllLuminance bits (red+green+blue?)

Compressed Color Formats

X3TC FormatsBits/BlockBlockBC#Alpha
Format::DXT1644x4BC11-bit
Format::DXT21284x4BC2Sharp, premul
Format::DXT31284x4BC2Sharp, non-premul
Format::DXT41284x4BC3Gradient, premul
Format::DXT51284x4BC3Gradient, non-premul

Depth/Stencil Formats

FormatBits/PixelNative Endian Bits
Format::D16_LOCKABLE16dddddddddddddddd
Format::D3232dddddddddddddddddddddddddddddddd
Format::D15S116ddddddddddddddds
Format::D24S832ddddddddddddddddddddddddssssssss
Format::D24X832ddddddddddddddddddddddddxxxxxxxx
Format::D24X4S432ddddddddddddddddddddddddxxxxssss
Format::D1616dddddddddddddddd
Format::D32F_LOCKABLE32dddddddddddddddddddddddddddddddd
Format::D24FS832ddddddddddddddddddddddddssssssss
[Direct3DEx] Only
Format::D32_LOCKABLE32dddddddddddddddddddddddddddddddd
Format::X8_LOCKABLE8ssssssss

Data Formats

Uncategorized Formats

Implementations

Source

impl Format

pub const fn from_unchecked(format: D3DFORMAT) -> Self

Convert a raw D3DFORMAT value into a Format. This is probably safe… probably…

pub const fn into(self) -> D3DFORMAT

Convert a Format back into a D3DFORMAT.

Source

impl Format

pub const UNKNOWN: Format

Surface format is unknown

pub const Unknown: Format = Format::UNKNOWN

pub const R8G8B8: Format

pub const A8R8G8B8: Format

pub const X8R8G8B8: Format

pub const R5G6B5: Format

pub const X1R5G5B5: Format

pub const A1R5G5B5: Format

pub const A4R4G4B4: Format

pub const R3G3B2: Format

pub const A8: Format

pub const A8R3G3B2: Format

pub const X4R4G4B4: Format

pub const A2B10G10R10: Format

pub const A8B8G8R8: Format

pub const X8B8G8R8: Format

pub const G16R16: Format

pub const A2R10G10B10: Format

pub const A16B16G16R16: Format

pub const A8P8: Format

pub const P8: Format

pub const L8: Format

pub const A8L8: Format

pub const A4L4: Format

pub const V8U8: Format

pub const L6V5U5: Format

pub const X8L8V8U8: Format

pub const Q8W8V8U8: Format

pub const V16U16: Format

pub const A2W10V10U10: Format

pub const UYVY: Format

pub const R8G8_B8G8: Format

pub const YUY2: Format

pub const G8R8_G8B8: Format

pub const DXT1: Format

pub const DXT2: Format

pub const DXT3: Format

pub const DXT4: Format

pub const DXT5: Format

pub const D16_LOCKABLE: Format

pub const D32: Format

pub const D15S1: Format

pub const D24S8: Format

pub const D24X8: Format

pub const D24X4S4: Format

pub const D16: Format

pub const D32F_LOCKABLE: Format

pub const D24FS8: Format

pub const D32_LOCKABLE: Format

Direct3D 9Ex Only

pub const X8_LOCKABLE: Format

Direct3D 9Ex Only

pub const L16: Format

pub const VERTEXDATA: Format

pub const INDEX16: Format

pub const INDEX32: Format

pub const VertexData: Format = Format::VERTEXDATA

pub const Index16: Format = Format::INDEX16

pub const Index32: Format = Format::INDEX32

pub const Q16W16V16U16: Format

pub const MULTI2_ARGB8: Format

pub const R16F: Format

pub const G16R16F: Format

pub const A16B16G16R16F: Format

pub const R32F: Format

pub const G32R32F: Format

pub const A32B32G32R32F: Format

pub const CxV8U8: Format

pub const A1: Format

1-bit monochrome.

Direct3D 9Ex Only

pub const A2B10G10R10_XR_BIAS: Format

2.8-biased fixed point.

Direct3D 9Ex Only

pub const BINARYBUFFER: Format

Binary format indicating that the data has no inherent type.

Direct3D 9Ex Only

pub const BinaryBuffer: Format = Format::BINARYBUFFER

Binary format indicating that the data has no inherent type.

Direct3D 9Ex Only