PShadeCaps

Struct PShadeCaps 

pub struct PShadeCaps(/* private fields */);
[docs.microsoft.com] D3DPSHADECAPS_*

Shading operations capabilities. It is assumed, in general, that if a device supports a given command at all, it supports the d3d::Shade::Flat mode (as specified in the d3d::ShadeMode enumerated type). This flag specifies whether the driver can also support Gouraud shading and whether alpha color components are supported. When alpha components are not supported, the alpha value of colors generated is implicitly 255. This is the maximum possible alpha (that is, the alpha component is at full intensity).

The color, specular highlights, fog, and alpha interpolants of a triangle each have capability flags that an application can use to find out how they are implemented by the device driver.

Implementations

Source

impl PShadeCaps

pub const fn from_unchecked(d3d: DWORD) -> Self

Convert from an underlying winapi D3D... type. This is probably safe… probably…

pub const fn into(self) -> DWORD

Convert back into an underlying winapi D3D... type.

Source

impl PShadeCaps