pub struct SamplerStateType(/* private fields */);Expand description
[docs.microsoft.com] D3DSAMPLERSTATETYPE
Sampler states define texture sampling operations such as texture addressing and texture filtering. Some sampler states set-up vertex processing, and some set-up pixel processing. Sampler states can be saved and restored using stateblocks (see State Blocks Save and Restore State (Direct3D 9)).
Implementations
Sourceimpl Samp
impl Samp
Sourcepub const fn from_unchecked(d3d: D3DSAMPLERSTATETYPE) -> Self
pub const fn from_unchecked(d3d: D3DSAMPLERSTATETYPE) -> Self
Convert from an underlying winapi D3D... type.
This is probably safe… probably…
Sourcepub const fn into(self) -> D3DSAMPLERSTATETYPE
pub const fn into(self) -> D3DSAMPLERSTATETYPE
Convert back into an underlying winapi D3D... type.
Sourceimpl SamplerStateType
impl SamplerStateType
pub const AddressU: SamplerStateType
pub const AddressV: SamplerStateType
pub const AddressW: SamplerStateType
pub const BorderColor: SamplerStateType
pub const MagFilter: SamplerStateType
pub const MinFilter: SamplerStateType
pub const MipFilter: SamplerStateType
pub const MipMapLODBias: SamplerStateType
pub const MaxMipLevel: SamplerStateType
pub const MaxAnisotropy: SamplerStateType
pub const SRGBTexture: SamplerStateType
pub const ElementIndex: SamplerStateType
pub const DMapOffset: SamplerStateType