pub struct Surface(/* private fields */);Expand description
[docs.microsoft.com] (extends Resource) A dense 2-dimensional region of data, often belonging to a Texture
Methods from Deref<Target = Resource>
Sourcepub fn check_compatible_with(
&self,
device: &impl IDirect3DDevice9Ext,
method: &'static str,
) -> Result<(), MethodError>
pub fn check_compatible_with( &self, device: &impl IDirect3DDevice9Ext, method: &'static str, ) -> Result<(), MethodError>
Check if self is compatible with device, returning an Err(...) if it isn’t.