IDirect3DStateBlock9Ext

Trait IDirect3DStateBlock9Ext 

pub trait IDirect3DStateBlock9Ext: AsSafe<IDirect3DStateBlock9> {
    // Provided methods
    fn apply(&self) -> Result<(), MethodError> { ... }
    fn capture(&self) -> Result<(), MethodError> { ... }
    fn get_device(&self) -> Result<Device, MethodError> { ... }
}
[docs.microsoft.com] IDirect3DStateBlock9 extension methods

Methods

thindxdocs.microsoft.comDescription
applyApplyApply the state block to the current device state.
captureCaptureCapture the current value of states that are included in a stateblock.
get_deviceGetDeviceGets the device.

Provided Methods

fn apply(&self) -> Result<(), MethodError>

[docs.microsoft.com] IDirect3DStateBlock9::Apply

Apply the state block to the current device state.

Returns
fn capture(&self) -> Result<(), MethodError>

[docs.microsoft.com] IDirect3DStateBlock9::Capture

Capture the current value of states that are included in a stateblock.

Returns
fn get_device(&self) -> Result<Device, MethodError>

[docs.microsoft.com] IDirect3DStateBlock9::GetDevice

Gets the device.

Returns

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors