pub trait IDirect3DStateBlock9Ext: AsSafe<IDirect3DStateBlock9> {
// Provided methods
fn apply(&self) -> Result<(), MethodError> { ... }
fn capture(&self) -> Result<(), MethodError> { ... }
fn get_device(&self) -> Result<Device, MethodError> { ... }
}Expand description
[docs.microsoft.com] IDirect3DStateBlock9 extension methods
Methods
Provided Methods
Sourcefn apply(&self) -> Result<(), MethodError>
fn apply(&self) -> Result<(), MethodError>
[docs.microsoft.com] IDirect3DStateBlock9::Apply
Apply the state block to the current device state.
Returns
- D3DERR::INVALIDCALL
- Ok(
())
Sourcefn capture(&self) -> Result<(), MethodError>
fn capture(&self) -> Result<(), MethodError>
[docs.microsoft.com] IDirect3DStateBlock9::Capture
Capture the current value of states that are included in a stateblock.
Returns
- D3DERR::INVALIDCALL
- Ok(
())
Sourcefn get_device(&self) -> Result<Device, MethodError>
fn get_device(&self) -> Result<Device, MethodError>
[docs.microsoft.com] IDirect3DStateBlock9::GetDevice
Gets the device.
Returns
- D3DERR::INVALIDCALL (Pure device?)
- Ok(Device)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.